(compress output
&
{:keys [reduce-errors reduce-success entries]
:or {reduce-errors reduce-errors reduce-success reduce-success}})Writes a zip archive with entries to output. Output can be anything that is accepted by clojure.java.io/output-stream . Entries can be a collection of filenames or pairs [path -> input]. Path is a path to entry inside archive. Input can be anything that is accepted by clojure.java.io/input-stream or true (input value defaults to path).
Writes a zip archive with entries to output. Output can be anything that is accepted by clojure.java.io/output-stream . Entries can be a collection of filenames or pairs [path -> input]. Path is a path to entry inside archive. Input can be anything that is accepted by clojure.java.io/input-stream or true (input value defaults to path).
(do-zip input f)Reads zip archive from input and applies f to [ZipInputStream ZipEntry] for each entry. Input can be anything that's accepted by clojure.java.io/input-stream .
Reads zip archive from input and applies f to [ZipInputStream ZipEntry] for each entry. Input can be anything that's accepted by clojure.java.io/input-stream .
(extract input output)Extracts input archive to output directory. Input can be anything that's accepted by clojure.java.io/input-stream . Output can be anything that is accepted by clojure.java.io/file .
Extracts input archive to output directory. Input can be anything that's accepted by clojure.java.io/input-stream . Output can be anything that is accepted by clojure.java.io/file .
(reduce-zip f val input)Reads zip archive from input and reduces all entries applying f to [ZipInputStream val ZipEntry]. Result of f becomes new val. Input can be anything that's accepted by clojure.java.io/input-stream .
Reads zip archive from input and reduces all entries applying f to [ZipInputStream val ZipEntry]. Result of f becomes new val. Input can be anything that's accepted by clojure.java.io/input-stream .
(seek-entry input entry-name f)Reads zip archive from input and searches for entry with name entry-name. Applies f to [ZipInputStream ZipEntry] if entry is found. Input can be anything that's accepted by clojure.java.io/input-stream .
Reads zip archive from input and searches for entry with name entry-name. Applies f to [ZipInputStream ZipEntry] if entry is found. Input can be anything that's accepted by clojure.java.io/input-stream .
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |